@@ -1,5 +1,5 @@
 package POEx::IRC::Backend;
-$POEx::IRC::Backend::VERSION = '0.024006';
+$POEx::IRC::Backend::VERSION = '0.025001';
 use strictures 1;
 use Carp;
 
@@ -8,8 +8,6 @@ use IRC::Message::Object 'ircmsg';
 use Net::IP::Minimal 'ip_is_ipv6';
 
 use POE qw/
-  Session
-
   Wheel::ReadWrite
   Wheel::SocketFactory
 
@@ -34,7 +32,9 @@ use POEx::IRC::Backend::Listener;
 use POEx::IRC::Backend::_Util;
 
 
-use namespace::clean;
+sub RUNNING_IN_HELL () { $^O =~ /(cygwin|MSWin32)/ }
+
+
 use Moo; use MooX::late;
 
 
@@ -87,9 +87,9 @@ has filter => (
   },
 );
 
-## POEx::IRC::Backend::Listener objs
-## These are listeners for a particular port.
 has listeners => (
+  ## POEx::IRC::Backend::Listener objs
+  ## These are listeners for a particular port.
   init_arg => undef,
   is      => 'ro',
   isa     => HashRef,
@@ -97,9 +97,9 @@ has listeners => (
   default => sub { +{} },
 );
 
-## POEx::IRC::Backend::Connector objs
-## These are outgoing (peer) connectors.
 has connectors => (
+  ## POEx::IRC::Backend::Connector objs
+  ## These are outgoing (peer) connectors.
   init_arg => undef,
   is      => 'ro',
   isa     => HashRef,
@@ -107,9 +107,9 @@ has connectors => (
   default => sub { +{} },
 );
 
-## POEx::IRC::Backend::Connect objs
-## These are our connected wheels.
 has wheels => (
+  ## POEx::IRC::Backend::Connect objs
+  ## These are our connected wheels.
   init_arg => undef,
   is      => 'ro',
   isa     => HashRef,
@@ -118,62 +118,67 @@ has wheels => (
 );
 
 
+my %_can_haz;
+
+sub has_ssl_support {
+  unless (defined $_can_haz{ssl}) {
+    try {; require POE::Component::SSLify; $_can_haz{ssl} = 1 }
+      catch {; $_can_haz{ssl} = 0 };
+  }
+  $_can_haz{ssl}
+}
+
+sub has_zlib_support {
+  unless (defined $_can_haz{zlib}) {
+    try {; require POE::Filter::Zlib::Stream; $_can_haz{zlib} = 1 }
+      catch {; $_can_haz{zlib} = 0 };
+  }
+  $_can_haz{zlib}
+}
+
+
 sub spawn {
-  ## Create our object and session.
-  ## Returns $self
-  ## Sets session_id()
   my ($class, %args) = @_;
+  my $ssl_opts = delete $args{ssl_opts};
+  my $self = blessed $class ? $class : $class->new(%args);
 
-  $args{lc $_} = delete $args{$_} for keys %args;
-
-  my $self = ref $class ? $class : $class->new;
-
-  my $sess_id = POE::Session->create(
+  POE::Session->create(
     object_states => [
       $self => {
-        '_start' => '_start',
-        '_stop'  => '_stop',
+        _start => '_start',
+        _stop  => '_stop',
 
-        'register' => '_register_controller',
-        'shutdown' => '_shutdown',
+        register          => '_register_controller',
+        shutdown          => '_shutdown',
+        create_connector  => '_create_connector',
+        create_listener   => '_create_listener',
+        remove_listener   => '_remove_listener',
+        send              => '_send',
 
-        'send' => '_send',
+        _accept_conn_v4   => '_accept_conn',
+        _accept_conn_v6   => '_accept_conn',
+        _accept_fail      => '_accept_fail',
+        _idle_alarm       => '_idle_alarm',
 
-        'create_listener' => '_create_listener',
-        'remove_listener' => '_remove_listener',
+        _connector_up_v4  => '_connector_up',
+        _connector_up_v6  => '_connector_up',
+        _connector_failed => '_connector_failed',
 
-        '_accept_conn_v4' => '_accept_conn',
-        '_accept_conn_v6' => '_accept_conn',
-        '_accept_fail' => '_accept_fail',
-        '_idle_alarm'  => '_idle_alarm',
-
-        'create_connector'  => '_create_connector',
-        '_connector_up_v4'  => '_connector_up',
-        '_connector_up_v6'  => '_connector_up',
-        '_connector_failed' => '_connector_failed',
-
-        '_ircsock_input'    => '_ircsock_input',
-        '_ircsock_error'    => '_ircsock_error',
-        '_ircsock_flushed'  => '_ircsock_flushed',
+        _ircsock_input    => '_ircsock_input',
+        _ircsock_error    => '_ircsock_error',
+        _ircsock_flushed  => '_ircsock_flushed',
       },
     ],
-  )->ID;
+  ) or confess "Failed to spawn POE::Session";
 
-  confess "Unable to spawn POE::Session and retrieve ID()"
-    unless $sess_id;
-
-  ## ssl_opts => [ ]
   ##  FIXME document that we need a pubkey + cert for server-side ssl
-  if ($args{ssl_opts}) {
-    confess "ssl_opts should be an ARRAY"
-      unless ref $args{ssl_opts} eq 'ARRAY';
-
+  if (defined $ssl_opts) {
+    confess "expected ssl_opts to be an ARRAY but got $ssl_opts"
+      unless ref $ssl_opts eq 'ARRAY';
     my $ssl_err;
     try {
-      require POE::Component::SSLify;
-      POE::Component::SSLify::SSLify_Options(
-        @{ $args{ssl_opts} }
-      );
+      die "Failed to load POE::Component::SSLify" unless $self->has_ssl_support;
+      POE::Component::SSLify::SSLify_Options( @$ssl_opts );
       1
     } catch {
       $ssl_err = $_;
@@ -181,12 +186,9 @@ sub spawn {
     } or confess "SSLify failure: $ssl_err";
   }
 
-  ## FIXME add listeners / connectors here if they're configured?
-
   $self
 }
 
-
 sub _start {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
   $self->_set_session_id( $_[SESSION]->ID );
@@ -198,20 +200,17 @@ sub _stop {
 
 sub shutdown {
   my $self = shift;
-  $poe_kernel->post( $self->session_id => 
-    shutdown => @_ 
-  )
+  $poe_kernel->post( $self->session_id => shutdown => @_ )
 }
 
 sub _shutdown {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
 
-  $kernel->refcount_decrement( $self->session_id, "IRCD Running" );
-  $kernel->refcount_decrement( $self->controller, "IRCD Running" );
+  $kernel->refcount_decrement( $self->session_id => "IRCD Running" );
+  $kernel->refcount_decrement( $self->controller => "IRCD Running" );
 
   ## _disconnected should also clear our alarms.
-  $self->_disconnected($_, "Server shutdown")
-    for keys %{ $self->wheels || {} };
+  $self->_disconnected($_, "Server shutdown") for keys %{ $self->wheels };
 
   for my $attr (map {; '_set_'.$_ } qw/ listeners connectors wheels /) {
     $self->$attr(+{})
@@ -219,23 +218,19 @@ sub _shutdown {
 }
 
 sub _register_controller {
-  ## 'register' event sets a controller session.
   my ($kernel, $self) = @_[KERNEL, OBJECT];
 
-  $kernel->refcount_decrement( $self->controller, "IRCD Running" )
+  $kernel->refcount_decrement( $self->controller => "IRCD Running" )
     if $self->has_controller;
   $self->_set_controller( $_[SENDER]->ID );
-  $kernel->refcount_increment( $self->controller, "IRCD Running" );
+  $kernel->refcount_increment( $self->controller => "IRCD Running" );
 
-  $kernel->post( $self->controller => 
-    ircsock_registered => $self 
-  );
+  $kernel->post( $self->controller => ircsock_registered => $self );
 }
 
 sub _accept_conn {
   ## Accepted connection to a listener.
-  my (undef, $self) = @_[KERNEL, OBJECT];
-  my ($sock, $p_addr, $p_port, $listener_id) = @_[ARG0 .. ARG3];
+  my ($self, $sock, $p_addr, $p_port, $listener_id) = @_[OBJECT, ARG0 .. ARG3];
 
   my ($un_p_addr, $protocol);
   if ($_[STATE] eq '_accept_conn_v6') {
@@ -243,18 +238,15 @@ sub _accept_conn {
     $un_p_addr = $p_addr;
   } else {
     $protocol  = 4;
-    $un_p_addr = get_unpacked_addr( pack_sockaddr_in($p_port, $p_addr),
-      noserv => 1
+    $un_p_addr = get_unpacked_addr(
+      pack_sockaddr_in($p_port, $p_addr), noserv => 1
     );
   }
-
-  my $sock_packed = getsockname $sock;
-  my ($sockaddr, $sockport) = get_unpacked_addr($sock_packed);
   my $listener = $self->listeners->{$listener_id};
 
   if ( $listener->ssl ) {
     try {
-      require POE::Component::SSLify;
+      die "Failed to load POE::Component::SSLify" unless $self->has_ssl_support;
       $sock = POE::Component::SSLify::Client_SSLify($sock)
     } catch {
       warn "Could not SSLify (server) socket: $_\n";
@@ -275,30 +267,21 @@ sub _accept_conn {
     return
   }
 
-  my $w_id = $wheel->ID;
-
+  my ($sockaddr, $sockport) = get_unpacked_addr( getsockname $sock );
   my $this_conn = POEx::IRC::Backend::Connect->new(
-    protocol => $protocol,
-    wheel    => $wheel,
-
-    peeraddr => $un_p_addr,
-    peerport => $p_port,
-
-    sockaddr => $sockaddr,
-    sockport => $sockport,
-
-    seen => time,
-    idle => $listener->idle,
+    protocol  => $protocol,
+    wheel     => $wheel,
+    peeraddr  => $un_p_addr,
+    peerport  => $p_port,
+    sockaddr  => $sockaddr,
+    sockport  => $sockport,
+    seen      => time,
+    idle      => $listener->idle,
   );
 
-  $self->wheels->{$w_id} = $this_conn;
-
+  $self->wheels->{ $wheel->ID } = $this_conn;
   $this_conn->alarm_id(
-    $poe_kernel->delay_set(
-      '_idle_alarm',
-      $this_conn->idle,
-      $w_id
-    )
+    $poe_kernel->delay_set( _idle_alarm => $this_conn->idle, $wheel->ID )
   );
 
   $poe_kernel->post( $self->controller => 
@@ -307,19 +290,13 @@ sub _accept_conn {
 }
 
 sub _idle_alarm {
-  my ($kernel, $self) = @_[KERNEL, OBJECT];
-  my $w_id = $_[ARG0];
-
+  my ($kernel, $self, $w_id) = @_[KERNEL, OBJECT, ARG0];
   my $this_conn = $self->wheels->{$w_id} || return;
 
-  $kernel->post( $self->controller => 
-    ircsock_connection_idle => $this_conn
-  );
+  $kernel->post( $self->controller => ircsock_connection_idle => $this_conn );
 
   $this_conn->alarm_id(
-    $kernel->delay_set( _idle_alarm => 
-      $this_conn->idle, $w_id
-    )
+    $kernel->delay_set( _idle_alarm => $this_conn->idle, $w_id )
   );
 }
 
@@ -342,23 +319,13 @@ sub _accept_fail {
 sub create_listener {
   my $self = shift;
 
-  $poe_kernel->post( $self->session_id =>
-    create_listener => @_
-  );
+  $poe_kernel->post( $self->session_id => create_listener => @_ );
 
   $self
 }
 
 sub _create_listener {
-  ## Create a listener on a particular port.
-  ##  bindaddr =>
-  ##  port =>
-  ## [optional]
-  ##  ipv6 =>
-  ##  ssl  =>
-  my ($kernel, $self) = @_[KERNEL, OBJECT];
-  my %args = @_[ARG0 .. $#_];
-
+  my ($kernel, $self, %args) = @_[KERNEL, OBJECT, ARG0 .. $#_];
   $args{lc $_} = delete $args{$_} for keys %args;
 
   my $bindaddr  = $args{bindaddr} || '0.0.0.0';
@@ -393,7 +360,6 @@ sub _create_listener {
   my (undef, $port) = get_unpacked_addr( $wheel->getsockname );
   $listener->set_port($port) if $port;
 
-  ## Tell our controller session
   $kernel->post( $self->controller => 
     ircsock_listener_created => $listener
   );
@@ -402,9 +368,7 @@ sub _create_listener {
 sub remove_listener {
   my $self = shift;
 
-  $poe_kernel->post( $self->session_id =>
-    remove_listener => @_
-  );
+  $poe_kernel->post( $self->session_id => remove_listener => @_ );
 
   $self
 }
@@ -457,9 +421,7 @@ sub _remove_listener {
 sub create_connector {
   my $self = shift;
 
-  $poe_kernel->post( $self->session_id =>
-    create_connector => @_
-  );
+  $poe_kernel->post( $self->session_id => create_connector => @_ );
 
   $self
 }
@@ -488,7 +450,7 @@ sub _create_connector {
       delete($args{ipv6})                                ? 6
     : ip_is_ipv6($remote_addr)                           ? 6
     : ( $args{bindaddr} && ip_is_ipv6($args{bindaddr}) ) ? 6
-    : 4;
+                                                         : 4;
 
   my $wheel = POE::Wheel::SocketFactory->new(
     SocketDomain   => ($protocol == 6 ? AF_INET6 : AF_INET),
@@ -529,9 +491,8 @@ sub _create_connector {
 
 
 sub _connector_up {
-  ## Created connector socket.
-  my ($kernel, $self) = @_[KERNEL, OBJECT];
-  my ($sock, $p_addr, $p_port, $c_id) = @_[ARG0 .. ARG3];
+  my ($kernel, $self, $sock, $p_addr, $p_port, $c_id)
+    = @_[KERNEL, OBJECT, ARG0 .. ARG3];
 
   my ($protocol, $un_p_addr);
   if ($_[STATE] eq '_connector_up_v6') {
@@ -539,17 +500,17 @@ sub _connector_up {
     $un_p_addr = $p_addr;
   } else {
     $protocol  = 4;
-    $un_p_addr = get_unpacked_addr( pack_sockaddr_in($p_port, $p_addr),
-      noserv => 1
+    $un_p_addr = get_unpacked_addr(
+      pack_sockaddr_in($p_port, $p_addr), noserv => 1
     );
   }
 
-  ## No need to try to connect out any more; remove from connectors pool
+  ## No need to try to connect out any more; remove from connectors pool:
   my $ct = delete $self->connectors->{$c_id};
 
   if ( $ct->ssl ) {
     try {
-      require POE::Component::SSLify;
+      die "Failed to load POE::Component::SSLify" unless $self->has_ssl_support;
       $sock = POE::Component::SSLify::Client_SSLify($sock)
     } catch {
       warn "Could not SSLify (client) socket: $_\n";
@@ -572,10 +533,7 @@ sub _connector_up {
     return
   }
 
-  my $w_id = $wheel->ID;
-
-  my $sock_packed = getsockname $sock;
-  my ($sockaddr, $sockport) = get_unpacked_addr($sock_packed);
+  my ($sockaddr, $sockport) = get_unpacked_addr( getsockname $sock );
 
   my $this_conn = POEx::IRC::Backend::Connect->new(
     protocol => $protocol,
@@ -587,7 +545,7 @@ sub _connector_up {
     seen => time,
   );
 
-  $self->wheels->{$w_id} = $this_conn;
+  $self->wheels->{ $wheel->ID } = $this_conn;
 
   $kernel->post( $self->controller => 
     ircsock_connector_open => $this_conn
@@ -610,11 +568,9 @@ sub _connector_failed {
 
 ## _ircsock_* handlers talk to endpoints via listeners/connectors
 sub _ircsock_input {
-  ## Input handler.
   my ($kernel, $self) = @_[KERNEL, OBJECT];
   my ($input, $w_id)  = @_[ARG0, ARG1];
 
-  ## Retrieve Backend::Connect
   my $this_conn = $self->wheels->{$w_id};
 
   ## Adjust last seen and idle alarm
@@ -624,7 +580,6 @@ sub _ircsock_input {
 
   ## FIXME configurable raw events?
 
-  ## Send ircsock_input to controller/dispatcher
   $kernel->post( $self->controller => 
     ircsock_input => $this_conn, ircmsg(%$input)
   );
@@ -645,23 +600,17 @@ sub _ircsock_error {
 
 sub _ircsock_flushed {
   ## Socket's been flushed; we may have something to do.
-  my (undef, $self, $w_id) = @_[KERNEL, OBJECT, ARG0];
+  my ($self, $w_id) = @_[OBJECT, ARG0];
 
   my $this_conn = $self->wheels->{$w_id} || return;
 
   if ($this_conn->is_disconnecting) {
-    $self->_disconnected(
-      $w_id,
-      $this_conn->is_disconnecting
-    );
-    return
+    return $self->_disconnected( $w_id, $this_conn->is_disconnecting )
   }
 
   if ($this_conn->is_pending_compress) {
-    $self->set_compressed_link_now($w_id);
-    return
+    return $self->set_compressed_link_now($w_id)
   }
-
 }
 
 sub _send {
@@ -675,26 +624,23 @@ sub send {
   ## ->send(HASH, ID [, ID .. ])
   my ($self, $out, @ids) = @_;
 
-  if ( is_Object($out) ) {
-
-    if      ( $out->isa('IRC::Message::Object') ) {
-      $out = +{
-        command => $out->command,
-        ( $out->has_prefix ? (prefix  => $out->prefix) : () ),
-        ( $out->has_params ? (params  => $out->params) : () ),
-        ( $out->has_tags   ? (tags    => $out->tags  ) : () ),
-      };
-    } else {
-      confess "No idea what to do with $out",
-    }
-
+  if (blessed $out && $out->isa('IRC::Message::Object')) {
+    $out = +{
+      command => $out->command,
+      ( $out->has_prefix ? (prefix  => $out->prefix) : () ),
+      ( $out->has_params ? (params  => $out->params) : () ),
+      ( $out->has_tags   ? (tags    => $out->tags  ) : () ),
+    };
   }
 
-  confess "send() takes a HASH and a list of connection IDs"
+  confess 
+    "send() takes a HASH or IRC::Message::Object and a list of connection IDs"
     unless ref $out eq 'HASH' and @ids;
 
-  for my $id (grep { $self->wheels->{$_} } @ids) {
-    $self->wheels->{$id}->wheel->put( $out );
+  TARGET: for my $target (@ids) {
+    # FIXME tests/docs wrt passing in Connect objs
+    $target = $target->wheel_id if blessed $target;
+    ($self->wheels->{$target} || next TARGET)->wheel->put($out)
   }
 
   $self
@@ -704,11 +650,9 @@ sub disconnect {
   ## Mark a wheel for disconnection.
   my ($self, $w_id, $str) = @_;
 
-  confess "disconnect() needs a wheel ID"
-    unless defined $w_id;
-
-  confess "disconnect() called for nonexistant wheel ID $w_id"
-    unless defined $self->wheels->{$w_id};
+  confess "disconnect() needs an (extant) wheel ID"
+    unless defined $w_id
+    and    defined $self->wheels->{$w_id};
 
   $self->wheels->{$w_id}->is_disconnecting(
     $str || "Client disconnect"
@@ -725,10 +669,10 @@ sub _disconnected {
   my $this_conn = delete $self->wheels->{$w_id};
 
   ## Idle timer cleanup
-  $poe_kernel->alarm_remove( $this_conn->alarm_id )
+  $poe_kernel->alarm_remove( $this_conn->alarm_id ) 
     if $this_conn->has_alarm_id;
 
-  if ($^O =~ /(cygwin|MSWin32)/) {
+  if (RUNNING_IN_HELL) {
     $this_conn->wheel->shutdown_input;
     $this_conn->wheel->shutdown_output;
   }
@@ -747,13 +691,16 @@ sub _disconnected {
 
 sub set_compressed_link {
   my ($self, $w_id) = @_;
-
-  require POE::Filter::Zlib::Stream;
-
   confess "set_compressed_link() needs a wheel ID"
     unless defined $w_id;
 
-  return unless $self->wheels->{$w_id};
+  confess "Failed to load POE::Filter::Zlib::Stream"
+    unless $self->has_zlib_support;
+
+  unless ($self->wheels->{$w_id}) {
+    carp "set_compressed_link for nonexistant wheel '$w_id'";
+    return
+  }
 
   $self->wheels->{$w_id}->is_pending_compress(1);
 
@@ -762,17 +709,20 @@ sub set_compressed_link {
 
 sub set_compressed_link_now {
   my ($self, $w_id) = @_;
-
-  require POE::Filter::Zlib::Stream;
-
   confess "set_compressed_link() needs a wheel ID"
     unless defined $w_id;
  
-  my $this_conn;
-  return unless $this_conn = $self->wheels->{$w_id};
+  my $this_conn = $self->wheels->{$w_id};
+  unless (defined $this_conn) {
+    carp "set_compressed_link_now for nonexistant wheel '$w_id'";
+    return
+  }
+
+  confess "Failed to load POE::Filter::Zlib::Stream"
+    unless $self->has_zlib_support;
 
   $this_conn->wheel->get_input_filter->unshift(
-    POE::Filter::Zlib::Stream->new,
+    POE::Filter::Zlib::Stream->new
   );
 
   $this_conn->is_pending_compress(0);
@@ -787,17 +737,17 @@ sub set_compressed_link_now {
 
 sub unset_compressed_link {
   my ($self, $w_id) = @_;
-
   confess "unset_compressed_link() needs a wheel ID"
     unless defined $w_id;
 
-  my $this_conn;
-  return unless $this_conn = $self->wheels->{$w_id};
-
-  return unless $this_conn->compressed;
+  my $this_conn = $self->wheels->{$w_id};
+  unless (defined $this_conn && $this_conn->compressed) {
+    carp 
+      "unset_compressed_link on uncompressed or nonexistant wheel '$w_id'";
+    return
+  }
 
   $this_conn->wheel->get_input_filter->shift;
-
   $this_conn->set_compressed(0);
 
   $self
@@ -814,7 +764,7 @@ unless caller; 1;
 
 =pod
 
-=for Pod::Coverage has_\w+
+=for Pod::Coverage has_\w+ RUNNING_IN_HELL
 
 =head1 NAME
 
@@ -825,62 +775,68 @@ POEx::IRC::Backend - IRC client or server backend
   use POE;
   use POEx::IRC::Backend;
 
-  ## Spawn a Backend and register as the controlling session:
-  my $backend = POEx::IRC::Backend->spawn;
-  $poe_kernel->post( $backend->session_id, 'register' );
+  POE::Session->create(
+    package_states => [
+      main => [ qw/
+        _start
+        ircsock_registered
+        ircsock_input
+      / ],
+    ],
+  );
+
+  sub _start {
+    # Spawn a Backend and register as the controlling session:
+    my $backend = POEx::IRC::Backend->spawn;
+    $_[HEAP]->{backend} = $backend;
+    $_[KERNEL]->post( $backend->session_id, 'register' );
+  }
 
   sub ircsock_registered {
-    my ($kernel, $self) = @_[KERNEL, OBJECT];
+    my $backend = $_[HEAP]->{backend};
 
-    ## Listen for incoming IRC traffic:
+    # Listen for incoming IRC traffic:
     $backend->create_listener(
       bindaddr => $addr,
       port     => $port,
     );
 
-    ## Connect to a remote endpoint:
+    # Connect to a remote endpoint:
     $backend->create_connector(
       remoteaddr => $remote,
       remoteport => $remoteport,
-      ## Optional:
+      # Optional:
       bindaddr => $bindaddr,
       ipv6     => 1,
       ssl      => 1,
     );
   }
 
-  ## Handle and dispatch incoming IRC events:
+  # Handle and dispatch incoming IRC events:
   sub ircsock_input {
-    my ($kernel, $self) = @_[KERNEL, OBJECT];
-
-    ## POEx::IRC::Backend::Connect obj:
+    # POEx::IRC::Backend::Connect obj:
     my $this_conn = $_[ARG0];
 
-    ## IRC::Message::Object obj:
+    # IRC::Message::Object obj:
     my $input_obj = $_[ARG1];
 
     my $cmd = $input_obj->command;
 
-    ## ... dispatch, etc ...
+    # ... dispatch, etc ...
   }
 
 =head1 DESCRIPTION
 
-A L<POE> IRC backend socket handler using L<POE::Filter::IRCv3> and
-L<IRC::Toolkit>.
-
-This can be used by client or server libraries to speak IRC protocol via
+A L<POE> IRC socket handler that can be used (by client or server
+implementations) to speak the IRC protocol to endpoints via
 L<IRC::Message::Object> objects.
 
-This is a basic low-level interface to IRC connections; 
-see L<POEx::IRC::Client::Lite> for an experimental IRC client library using
-this backend.
+Inspired by L<POE::Component::Server::IRC::Backend> & L<POE::Component::IRC>.
 
-This module is part of a set of IRC building blocks that have been 
-split out of a much larger project; it is also early 'alpha-quality' software.
-
-Take a gander at L<POE::Component::IRC> for a mature, fully-featured IRC
-client library.
+This is a very low-level interface to IRC sockets. See
+L<POEx::IRC::Client::Lite> for an experimental IRC client library using this
+backend (and the L</"SEE ALSO"> section of this documentation for related
+tools).
 
 =head2 Attributes
 
@@ -1008,14 +964,38 @@ disconnection.
     command => 'PRIVMSG',
     params  => [ $chan, $string ],
   );
-  $backend->send( $msg, $connect_id );
+  $backend->send( $msg, $connect_obj );
 
 Feeds L<POE::Filter::IRCv3> and sends the resultant raw IRC 
-line to the specified connection wheel ID(s).
+line to the specified connection wheel ID(s) or L<POEx::IRC::Backend::Connect>
+object(s).
 
 Accepts either an L<IRC::Message::Object> or a HASH compatible with
 L<POE::Filter::IRCv3> -- look there for details.
 
+Note that unroutable (target connection IDs with no matching live
+wheel) messages are silently dropped. You can check L</wheels> yourself before
+sending if this behavior is unwanted:
+
+  for my $target (@connect_ids) {
+    unless (exists $backend->wheels->{$target}) {
+      warn "Cannot send to nonexistant target '$target'";
+      next
+    }
+    $backend->send(
+        { prefix => $prefix, params => [ @params ], command => $cmd },
+        $target
+    );
+  }
+
+=head3 has_ssl_support
+
+Returns true if L<POE::Component::SSLify> was successfully loaded.
+
+=head3 has_zlib_support
+
+Returns true if L<POE::Filter::Zlib::Stream> was successfully loaded.
+
 =head3 set_compressed_link
 
   $backend->set_compressed_link( $conn_id );
@@ -1024,6 +1004,8 @@ Mark a specified connection wheel ID as pending compression;
 L<POE::Filter::Zlib::Stream> will be added to the filter stack when the 
 next flush event arrives.
 
+This method will die unless L</has_zlib_support> is true.
+
 =head3 set_compressed_link_now
 
   $backend->set_compressed_link_now( $conn_id );
@@ -1031,6 +1013,8 @@ next flush event arrives.
 Add a L<POE::Filter::Zlib::Stream> to the connection's filter stack 
 immediately, rather than upon next flush event.
 
+This method will die unless L</has_zlib_support> is true.
+
 =head3 unset_compressed_link
 
   $backend->unset_compressed_link( $conn_id );
@@ -1172,16 +1156,23 @@ Zlib and SSL are mostly untested.
 
 =head1 SEE ALSO
 
-L<IRC::Toolkit>
+L<POEx::IRC::Client::Lite> for an experimental IRC client library using this
+backend.
 
-L<POE::Filter::IRCv3>
+L<POE::Filter::IRCv3> and L<IRC::Message::Object> for documentation regarding
+IRC message parsing.
+
+L<IRC::Toolkit> for an extensive set of IRC-related utilities.
+
+L<POE::Component::IRC> if you're looking for a mature, fully-featured IRC
+client library.
 
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
 
 Inspiration derived from L<POE::Component::Server::IRC::Backend> and
-L<POE::Component::IRC> by BINGOS, HINRIK et al
+L<POE::Component::IRC> by BINGOS, HINRIK et al.
 
 =cut
 
